<?php $TRANSLATIONS = array(
"Save" => "저장",
"Search" => "검색",
"Close" => "닫기",
"Next" => "다음",
"Clear" => "지우기",
"Saving..." => "저장하는 중...",
"Failed to save file" => "파일 저장 실패",
"An error occurred!" => "오류가 발생하였습니다!",
"There are unsaved changes in the text editor" => "저장되지 않은 변경 사항이 있습니다.",
"There were unsaved changes, click here to go back" => "저장되지 않은 변경 사항이 있습니다. 여기를 누르면 돌아갑니다"
);
